@@ -14,15 +14,15 @@ cd /tmp/ || die "Can't chdir to /tmp/ ."
 
 if [ ! -r kernel-3.14.27-100.fc19.src.rpm ]
 then
-    wget http://ftp.riken.jp/Linux/fedora/updates/19/SRPMS/kernel-3.14.27-100.fc19.src.rpm || die "Can't download source package."
+    wget https://archives.fedoraproject.org/pub/archive/fedora/linux/updates/19/SRPMS/kernel-3.14.27-100.fc19.src.rpm || die "Can't download source package."
 fi
-rpm --checksig kernel-3.14.27-100.fc19.src.rpm || die "Can't verify signature."
+LANG=C rpm --checksig kernel-3.14.27-100.fc19.src.rpm | grep -F ': rsa sha1 (md5) pgp md5 OK' || die "Can't verify signature."
 rpm -ivh kernel-3.14.27-100.fc19.src.rpm || die "Can't install source package."
 
 cd /root/rpmbuild/SOURCES/ || die "Can't chdir to /root/rpmbuild/SOURCES/ ."
-if [ ! -r ccs-patch-1.8.3-20150112.tar.gz ]
+if [ ! -r ccs-patch-1.8.3-20150403.tar.gz ]
 then
-    wget -O ccs-patch-1.8.3-20150112.tar.gz 'http://sourceforge.jp/frs/redir.php?f=/tomoyo/49684/ccs-patch-1.8.3-20150112.tar.gz' || die "Can't download patch."
+    wget -O ccs-patch-1.8.3-20150403.tar.gz 'http://sourceforge.jp/frs/redir.php?f=/tomoyo/49684/ccs-patch-1.8.3-20150403.tar.gz' || die "Can't download patch."
 fi
 
 cd /root/rpmbuild/SPECS/ || die "Can't chdir to /root/rpmbuild/SPECS/ ."
@@ -71,7 +71,7 @@ patch << "EOF" || die "Can't patch spec file."
  # END OF PATCH APPLICATIONS
  
 +# TOMOYO Linux
-+tar -zxf %_sourcedir/ccs-patch-1.8.3-20150112.tar.gz
++tar -zxf %_sourcedir/ccs-patch-1.8.3-20150403.tar.gz
 +patch -sp1 < patches/ccs-patch-3.14-fedora-19.diff
 +
  %endif
