@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2005-2012  NTT DATA CORPORATION
  *
- * Version: 1.8.3+   2012/05/05
+ * Version: 1.8.3+   2015/01/12
  */
 
 #ifndef _SECURITY_CCSECURITY_INTERNAL_H
@@ -360,6 +360,10 @@ static inline void __list_del_entry(struct list_head *entry)
 
 #if LINUX_VERSION_CODE < KERNEL_VERSION(2, 4, 30) || (LINUX_VERSION_CODE >= KERNEL_VERSION(2, 5, 0) && LINUX_VERSION_CODE < KERNEL_VERSION(2, 6, 9))
 
+#if LINUX_VERSION_CODE == KERNEL_VERSION(2, 4, 21)
+#undef ssleep
+#endif
+
 #ifndef ssleep
 
 /**
